#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import time
import unittest

import amulet

import yaml


class BundleTest(unittest.TestCase):
    """Basic deployment and function test for rsyslog."""

    @classmethod
    def setUpClass(cls):
        """Make sure test env is setup."""
        cls.d = amulet.Deployment(series='xenial')

        bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
        with open(bundle_path, 'r') as bundle_file:
            contents = yaml.safe_load(bundle_file)
            cls.d.load(contents)
        cls.d.setup(timeout=900)
        cls.d.sentry.wait(timeout=900)
        cls.d.sentry.wait_for_messages({'syslog-source': 'ready'}, timeout=900)
        cls.rsyslog = cls.d.sentry['rsyslog'][0]
        cls.source = cls.d.sentry['syslog-source'][0]

    def test_deployed(self):
        """Test to see if the bundle deployed successfully."""
        self.assertTrue(self.d.deployed)

    def test_rsyslog(self):
        """Make sure syslog data is being logged."""
        # Generate syslog data and watch for it on the rsyslog unit (up to 5m)
        start = time.time()
        while time.time() - start < 300:
            self.source.ssh("logger 'amulet-testing'")
            output, rc = self.rsyslog.ssh("grep amulet-testing /var/log/syslog")
            if 'amulet-testing' in output:
                return True
            time.sleep(5)
        self.fail('rsyslog did not find expected data from syslog-source')


if __name__ == '__main__':
    unittest.main()
